==> qucs-0.0.8.tar.gz: qucs-0.0.8/qucs/dialogs/settingsdialog.h <==
/***************************************************************************
                          settingsdialog.h  -  description
                             -------------------
    begin                : Mon Oct 20 2003
    copyright            : (C) 2003 by Michael Margraf
    email                : michael.margraf@alumni.tu-berlin.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include <qdialog.h>

class QucsDoc;
class QLineEdit;
class QCheckBox;
class QVBoxLayout;
class QRegExpValidator;

/**
  *@author Michael Margraf
  */

class SettingsDialog : public QDialog  {
   Q_OBJECT
public:
  SettingsDialog(QucsDoc *d, QWidget *parent=0, const char *name=0);
  ~SettingsDialog();

private slots:
  void slotOK();
  void slotApply();

public:
  QucsDoc   *Doc;

  QLineEdit *Input_DataSet, *Input_DataDisplay;
  QLineEdit *Input_GridX, *Input_GridY;
  QCheckBox *Check_OpenDpl, *Check_GridOn;

  QVBoxLayout *all;
  QRegExpValidator *valExpr;
};

#endif

==> qucs-0.0.17.130503.tar.gz: qucs-0.0.17.130503/qucs/dialogs/settingsdialog.h <==
/***************************************************************************
                              settingsdialog.h
                             ------------------
    begin                : Mon Oct 20 2003
    copyright            : (C) 2003 by Michael Margraf
    email                : michael.margraf@alumni.tu-berlin.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include <qdialog.h>
//Added by qt3to4:
#include <Q3VBoxLayout>

class Schematic;
class QLineEdit;
class Q3TextEdit;
class QCheckBox;
class QComboBox;
class Q3VBoxLayout;
class QRegExpValidator;


class SettingsDialog : public QDialog  {
   Q_OBJECT
public:
  SettingsDialog(Schematic*);
 ~SettingsDialog();

private slots:
  void slotOK();
  void slotApply();

public:
  Schematic *Doc;

  QComboBox *Combo_Frame;
  Q3TextEdit *Input_Frame0;
  QLineEdit *Input_Frame1, *Input_Frame2, *Input_Frame3;
  QLineEdit *Input_DataSet, *Input_DataDisplay, *Input_Script;
  QLineEdit *Input_GridX, *Input_GridY;
  QCheckBox *Check_OpenDpl, *Check_GridOn, *Check_RunScript;

  Q3VBoxLayout *all;
  QRegExpValidator *valExpr;
};

#endif
